qcacmn: hif: Fix misspellings

Address the following issues in the hif folder:
CHECK: 'controll' may be misspelled - perhaps 'control'?
CHECK: 'Implemenation' may be misspelled - perhaps 'Implementation'?
CHECK: 'intialize' may be misspelled - perhaps 'initialize'?
CHECK: 'occuring' may be misspelled - perhaps 'occurring'?
CHECK: 'reseting' may be misspelled - perhaps 'resetting'?
CHECK: 'stuct' may be misspelled - perhaps 'struct'?
CHECK: 'substract' may be misspelled - perhaps 'subtract'?
CHECK: 'successfull' may be misspelled - perhaps 'successful'?
CHECK: 'syncronize' may be misspelled - perhaps 'synchronize'?
CHECK: 'transfered' may be misspelled - perhaps 'transferred'?
CHECK: 'untill' may be misspelled - perhaps 'until'?
CHECK: 'wirte' may be misspelled - perhaps 'write'?

Change-Id: I80280ecb8ac8b0270a32add74429a8df89bedbcb
CRs-Fixed: 2241576
diff --git a/hif/src/ce/ce_api.h b/hif/src/ce/ce_api.h
index d4641ad..2b50d0c 100644
--- a/hif/src/ce/ce_api.h
+++ b/hif/src/ce/ce_api.h
@@ -194,7 +194,7 @@
  *   transfer_id     - arbitrary ID; reflected to destination
  * Returns 0 on success; otherwise an error status.
  *
- * Implemenation note: Pushes multiple buffers with Gather to Source ring.
+ * Implementation note: Pushes multiple buffers with Gather to Source ring.
  */
 int ce_sendlist_send(struct CE_handle *copyeng,
 		void *per_transfer_send_context,
@@ -211,7 +211,7 @@
  *   buffer                     - address of buffer in CE space
  * Returns 0 on success; otherwise an error status.
  *
- * Implemenation note: Pushes a buffer to Dest ring.
+ * Implementation note: Pushes a buffer to Dest ring.
  */
 int ce_recv_buf_enqueue(struct CE_handle *copyeng,
 			void *per_transfer_recv_context,
@@ -308,7 +308,7 @@
  *    in a recv_cb function when processing buf_lists
  *    in a recv_cb function in order to mitigate recv_cb's.
  *
- * Implemenation note: Pops buffer from Dest ring.
+ * Implementation note: Pops buffer from Dest ring.
  */
 int ce_completed_recv_next(struct CE_handle *copyeng,
 			   void **per_CE_contextp,
@@ -394,7 +394,7 @@
 #define CE_ATTR_DIAG                 0x20 /* Diag CE */
 
 /**
- * stuct CE_attr - Attributes of an instance of a Copy Engine
+ * struct CE_attr - Attributes of an instance of a Copy Engine
  * @flags:         CE_ATTR_* values
  * @priority:      TBD
  * @src_nentries:  #entries in source ring - Must be a power of 2
diff --git a/hif/src/ce/ce_internal.h b/hif/src/ce/ce_internal.h
index 828840b..ad14744 100644
--- a/hif/src/ce/ce_internal.h
+++ b/hif/src/ce/ce_internal.h
@@ -393,7 +393,7 @@
  * @FAST_TX_WRITE_INDEX_UPDATE: event recorded before updating the write index
  *	of the TX ring in fastpath
  * @FAST_TX_WRITE_INDEX_SOFTWARE_UPDATE: recored when dropping a write to
- *	the wirte index in fastpath
+ *	the write index in fastpath
  * @FAST_TX_SOFTWARE_INDEX_UPDATE: event recorded before updating the software
  *	index of the RX ring in fastpath
  * @HIF_IRQ_EVENT: event recorded in the irq before scheduling the bh
diff --git a/hif/src/ce/ce_main.c b/hif/src/ce/ce_main.c
index c42687a..8a197fe 100644
--- a/hif/src/ce/ce_main.c
+++ b/hif/src/ce/ce_main.c
@@ -996,7 +996,7 @@
  * ce_oom_recovery() - try to recover rx ce from oom condition
  * @context: CE_state of the CE with oom rx ring
  *
- * the executing work Will continue to be rescheduled untill
+ * the executing work Will continue to be rescheduled until
  * at least 1 descriptor is successfully posted to the rx ring.
  *
  * return: none
@@ -1459,7 +1459,7 @@
  * the TX CE has been processed completely.
  *
  * This is called while dismantling CE structures. No other thread
- * should be using these structures while dismantling is occuring
+ * should be using these structures while dismantling is occurring
  * therfore no locking is needed.
  *
  * Return: none
diff --git a/hif/src/ce/ce_service.c b/hif/src/ce/ce_service.c
index c408b3e..f253388 100644
--- a/hif/src/ce/ce_service.c
+++ b/hif/src/ce/ce_service.c
@@ -158,7 +158,7 @@
 /**
  * hif_record_ce_desc_event() - record ce descriptor events
  * @scn: hif_softc
- * @ce_id: which ce is the event occuring on
+ * @ce_id: which ce is the event occurring on
  * @type: what happened
  * @descriptor: pointer to the descriptor posted/completed
  * @memory: virtual address of buffer related to the descriptor
diff --git a/hif/src/ce/ce_tasklet.c b/hif/src/ce/ce_tasklet.c
index 8b2374c..937616b 100644
--- a/hif/src/ce/ce_tasklet.c
+++ b/hif/src/ce/ce_tasklet.c
@@ -229,7 +229,7 @@
 
 #define HIF_CE_DRAIN_WAIT_CNT          20
 /**
- * hif_drain_tasklets(): wait untill no tasklet is pending
+ * hif_drain_tasklets(): wait until no tasklet is pending
  * @scn: hif context
  *
  * Let running tasklets clear pending trafic.
diff --git a/hif/src/dispatcher/dummy.c b/hif/src/dispatcher/dummy.c
index c2590bb..beb4cfb 100644
--- a/hif/src/dispatcher/dummy.c
+++ b/hif/src/dispatcher/dummy.c
@@ -78,7 +78,7 @@
  * hif_dummy_suspend_noirq() - suspend the bus
  * @hif_ctx: hif context
  *
- * dummy for busses that don't need to syncronize
+ * dummy for busses that don't need to synchronize
  * with interrupt disable.
  *
  * Return: 0 for success and non-zero for failure
@@ -92,7 +92,7 @@
  * hif_dummy_resume_noirq() - resume the bus
  * @hif_ctx: hif context
  *
- * dummy for busses that don't need to syncronize
+ * dummy for busses that don't need to synchronize
  * with interrupt disable.
  *
  * Return: 0 for success and non-zero for failure
diff --git a/hif/src/pcie/if_pci.c b/hif/src/pcie/if_pci.c
index ce1b9f5..03ee4fa 100644
--- a/hif/src/pcie/if_pci.c
+++ b/hif/src/pcie/if_pci.c
@@ -466,7 +466,7 @@
 /* CPU warm reset function
  * Steps:
  * 1. Disable all pending interrupts - so no pending interrupts on WARM reset
- * 2. Clear the FW_INDICATOR_ADDRESS -so Traget CPU intializes FW
+ * 2. Clear the FW_INDICATOR_ADDRESS -so Traget CPU initializes FW
  *    correctly on WARM reset
  * 3. Clear TARGET CPU LF timer interrupt
  * 4. Reset all CEs to clear any pending CE tarnsactions
@@ -2657,7 +2657,7 @@
 
 #ifdef FEATURE_RUNTIME_PM
 /**
- * hif_runtime_prevent_linkdown() - prevent or allow a runtime pm from occuring
+ * hif_runtime_prevent_linkdown() - prevent or allow a runtime pm from occurring
  * @scn: hif context
  * @flag: prevent linkdown if true otherwise allow
  *
@@ -2936,7 +2936,7 @@
 /**
  * hif_log_runtime_resume_success() - log a successful runtime resume
  *
- * log a successfull runtime resume
+ * log a successful runtime resume
  * mark last busy to prevent immediate runtime suspend
  */
 static void hif_log_runtime_resume_success(void *hif_ctx)
@@ -3721,7 +3721,7 @@
 
 /**
  * hif_target_sync() : ensure the target is ready
- * @scn: hif controll structure
+ * @scn: hif control structure
  *
  * Informs fw that we plan to use legacy interupts so that
  * it can begin booting. Ensures that the fw finishes booting
@@ -3956,7 +3956,7 @@
 void hif_pci_irq_disable(struct hif_softc *scn, int ce_id)
 {
 	/* For Rome only need to wake up target */
-	/* target access is maintained untill interrupts are re-enabled */
+	/* target access is maintained until interrupts are re-enabled */
 	Q_TARGET_ACCESS_BEGIN(scn);
 }
 
@@ -3976,7 +3976,7 @@
 /**
  * hif_pm_runtime_get() - do a get opperation on the device
  *
- * A get opperation will prevent a runtime suspend untill a
+ * A get opperation will prevent a runtime suspend until a
  * corresponding put is done.  This api should be used when sending
  * data.
  *
diff --git a/hif/src/pcie/if_pci.h b/hif/src/pcie/if_pci.h
index 9f80a0e..d21f96d 100644
--- a/hif/src/pcie/if_pci.h
+++ b/hif/src/pcie/if_pci.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2017 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2013-2018 The Linux Foundation. All rights reserved.
  *
  * Permission to use, copy, modify, and/or distribute this software for
  * any purpose with or without fee is hereby granted, provided that the
@@ -160,7 +160,7 @@
 /*
  * There may be some pending tx frames during platform suspend.
  * Suspend operation should be delayed until those tx frames are
- * transfered from the host to target. This macro specifies how
+ * transferred from the host to target. This macro specifies how
  * long suspend thread has to sleep before checking pending tx
  * frame count.
  */
diff --git a/hif/src/sdio/hif_sdio_send.c b/hif/src/sdio/hif_sdio_send.c
index 2f9da42..1ea1494 100644
--- a/hif/src/sdio/hif_sdio_send.c
+++ b/hif/src/sdio/hif_sdio_send.c
@@ -118,7 +118,7 @@
 	frag_count = qdf_nbuf_get_num_frags(buf);
 
 	if (frag_count > 1) {
-		/* header data length should be total sending length substract
+		/* header data length should be total sending length subtract
 		 * internal data length of netbuf
 		 */
 		head_data_len = sizeof(struct hif_sendContext) +
diff --git a/hif/src/sdio/native_sdio/src/hif.c b/hif/src/sdio/native_sdio/src/hif.c
index 423cf2b..966101b 100644
--- a/hif/src/sdio/native_sdio/src/hif.c
+++ b/hif/src/sdio/native_sdio/src/hif.c
@@ -1984,7 +1984,7 @@
 		 * driver to re-enumerate the slot
 		 */
 		AR_DEBUG_PRINTF(ATH_DEBUG_WARN,
-				("%s: reseting SDIO card",
+				("%s: resetting SDIO card",
 				__func__));
 
 		/* sdio_f0_writeb() cannot be used here, this allows access
diff --git a/hif/src/usb/hif_usb.c b/hif/src/usb/hif_usb.c
index ad0caa7..1e5cd21 100644
--- a/hif/src/usb/hif_usb.c
+++ b/hif/src/usb/hif_usb.c
@@ -145,7 +145,7 @@
 	} else if ((frag_count - 1) <= QDF_NBUF_CB_TX_MAX_EXTRA_FRAGS) {
 		/*
 		 * means have extra fragment buf in skb
-		 * header data length should be total sending length substract
+		 * header data length should be total sending length subtract
 		 * internal data length of netbuf
 		 * | hif_usb_send_context | fragments except internal buffer |
 		 * netbuf->data
diff --git a/hif/src/usb/if_usb.h b/hif/src/usb/if_usb.h
index fde4d0d..130e08a 100644
--- a/hif/src/usb/if_usb.h
+++ b/hif/src/usb/if_usb.h
@@ -24,7 +24,7 @@
 /*
  * There may be some pending tx frames during platform suspend.
  * Suspend operation should be delayed until those tx frames are
- * transfered from the host to target. This macro specifies how
+ * transferred from the host to target. This macro specifies how
  * long suspend thread has to sleep before checking pending tx
  * frame count.
  */
diff --git a/hif/src/dispatcher/multibus.c b/hif/src/dispatcher/multibus.c
index da1666c..bf2b308 100644
--- a/hif/src/dispatcher/multibus.c
+++ b/hif/src/dispatcher/multibus.c
@@ -34,11 +34,11 @@
 #include "qdf_module.h"
 
 /**
  * hif_intialize_default_ops() - intializes default operations values
  *
  * bus specific features should assign their dummy implementations here.
  */
-static void hif_intialize_default_ops(struct hif_softc *hif_sc)
+static void hif_initialize_default_ops(struct hif_softc *hif_sc)
 {
 	struct hif_bus_ops *bus_ops = &hif_sc->bus_ops;
 
@@ -121,7 +121,7 @@
 {
 	QDF_STATUS status = QDF_STATUS_E_INVAL;
 
-	hif_intialize_default_ops(hif_sc);
+	hif_initialize_default_ops(hif_sc);
 
 	switch (bus_type) {
 	case QDF_BUS_TYPE_PCI:
@@ -34,11 +34,11 @@
 
 /**
- * hif_intialize_default_ops() - intializes default operations values
+ * hif_initialize_default_ops() - initializes default operations values
  *
  * bus specific features should assign their dummy implementations here.